Credits
=======

* `Diederik Veeze <https://github.com/didrix>`_ (Zest Software) is the
  creator of collective.ogtags.

* `Maurits van Rees <https://github.com/mauritsvanrees>`_ (Zest Software) is the
  maintainer of collective.ogtags.
